// 
// このコードは、https://demo.mescius.jp/diodocs/pdf のサンプルの一部として提供されています。
// © MESCIUS inc. All rights reserved.
// 
using System;
using System.IO;
using System.Drawing;
using GrapeCity.Documents.Pdf;
using GrapeCity.Documents.Text;
using GrapeCity.Documents.Pdf.Annotations;
using System.Collections.Generic;
using GrapeCity.Documents.Common;

namespace DsPdfWeb.Demos
{
    // このサンプルでは、PDF ドキュメント内の2つの単語をすべて検索し、検索結果すべてを
    // テキストマークアップ注釈のハイライトを使用して強調表示する方法を紹介しています。
    // このサンプルは FindAndUnderline と似ていますが、ここでは、検索結果ごとに
    // 個別の注釈を追加するのではなく、1ページごとに1つのテキストマークアップ注釈を作成し、
    // 強調表示する単語すべてを注釈に追加しています。
    public class MarkupPerPage
    {
        public int CreatePDF(Stream stream)
        {
            // PDF を読み込みます。
            var doc = new GcPdfDocument();
            using var fs = File.OpenRead(Path.Combine("Resources", "PDFs", "diodocs_flyer.pdf"));
            doc.Load(fs);

            // 正規表現を使用して、「Standard」と「API」をすべて検索します。
            var ft = new FindTextParams("Standard|API", wholeWord: false, matchCase: false, regex: true);
            var found = doc.FindText(ft, null);

            // ページごとにテキストマークアップ注釈を追加します（キーはページインデックス）。
            Dictionary<int, Tuple<TextMarkupAnnotation, List<Quadrilateral>>> markups = new Dictionary<int, Tuple<TextMarkupAnnotation, List<Quadrilateral>>>();
            foreach (var f in found)
            {
                if (!markups.TryGetValue(f.PageIndex, out var markup))
                {
                    markup = new Tuple<TextMarkupAnnotation, List<Quadrilateral>>(
                        new TextMarkupAnnotation()
                        {
                            Page = doc.Pages[f.PageIndex],
                            MarkupType = TextMarkupType.Highlight,
                            Color = Color.Chartreuse
                        },
                        new List<Quadrilateral>());
                    markups[f.PageIndex] = markup;
                }
                foreach (var b in f.Bounds)
                    markup.Item2.Add(b);
            }
            foreach (var v in markups.Values)
                v.Item1.Area = v.Item2;

            // PDF ドキュメントを保存します。
            doc.Save(stream);
            return doc.Pages.Count;
        }
    }
}
